Struct amazon_sp_reports::models::create_report_schedule_specification::CreateReportScheduleSpecification
source · [−]pub struct CreateReportScheduleSpecification {
pub report_type: String,
pub marketplace_ids: Vec<String>,
pub report_options: Option<HashMap<String, String>>,
pub period: Period,
pub next_report_creation_time: Option<String>,
}Fields
report_type: StringThe report type.
marketplace_ids: Vec<String>A list of marketplace identifiers for the report schedule.
report_options: Option<HashMap<String, String>>Additional information passed to reports. This varies by report type.
period: PeriodOne of a set of predefined ISO 8601 periods that specifies how often a report should be created.
next_report_creation_time: Option<String>The date and time when the schedule will create its next report, in ISO 8601 date time format.
Implementations